## ctcsound
Python bindings for Csound using ctypes. Can be used from python2.x and python3.x as well.  

This repository is closely tied to the develop branch of Csound. The version of ctcsound should
match the version of csound installed

Dependency: numpy
